#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_smarteam_integ_interfaces.sti_db_item import StiDBItem
from pycatia.system_interfaces.any_object import AnyObject


class StiEngine(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StiEngine
                | 
                | Represents the SmarTeam Integration Engine, that is to say the entry point to
                | the CATIA/SmarTeam Integration.
                | 
                | It allows end user to realize the following operations (also called StiEngine
                | methods): connection and disconnection to SmarTeam Integration, creation of
                | SmarTeam Integration Objects (StiDBItem) and management of their lifecycle
                | (Save, Check In, Check Out, Release, New Release, ...).
                | Note that all operations performed from this interface are the same as
                | operations available and launched from the SmarTeam menu in
                | CATIA.
                | Warning: By Default, these operations launched from this interface are executed
                | Without Panel.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the SmarTeam Integration
                |       Engine.
                | 
                |      Dim oStiEngine As StiEngine
                |      Set oStiEngine = CATIA.GetItem("CAIEngine")
                | 
                | See also:
                |     StiDBItem
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sti_engine = com_object

    @property
    def integration_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IntegrationType() As CATBSTR (Read Only)
                | 
                |     Returns the Engine Integration Type.
                |     Warning: Do Not use this method. It is Not implemented.

        :rtype: str
        """

        return self.sti_engine.IntegrationType

    @property
    def use_graphical_ui(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseGraphicalUI() As boolean
                | 
                |     Returns (gets) or sets the use of Graphical User Interface (GUI) in order
                |     to display or not panels. This method allows programmer to define if methods of
                |     this Interface Definition Language (IDL) will be executed With or Without user
                |     interactions.
                |     Warning: By Default, operations launched from this interface are executed
                |     Without GUI, that is to say 'UseGraphicalUI' is set to 'False'. In practice, No
                |     GUI means that treatments are executed With Default Values because additional
                |     parameters or options can not be set, as there is no user interaction. If GUI
                |     are allowed, panels will be displayed. These panels correspond to the usual
                |     ones displayed when the corresponding functionnalities are launched from the
                |     SmarTeam Intagration menu. The behaviour is so the same as in Interactive
                |     Mode.
                |     Note that the Connection to SmarTeam Integration is totally Independent of
                |     the Value of UseGraphicalUI.
                | 
                |     Example:
                | 
                |           The following example returns in the boolean bIsActive the current
                |           value of this option -that is to say 
                |          if we use or not GUI for StiEngine methods- and then sets it -if
                |          needed- to 'True' -that corresponds to GUI operating
                |          mode.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |              oStiEngine.UseGraphicalUI = True
                |          End If

        :rtype: bool
        """

        return self.sti_engine.UseGraphicalUI

    @use_graphical_ui.setter
    def use_graphical_ui(self, value: bool):
        """
        :param bool value:
        """

        self.sti_engine.UseGraphicalUI = value

    def build_doc_db_item_from_smar_team_id(self, iobject_id: int, iclass_id: int) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func BuildDocDBItemFromSmarTeamID(long iobjectId,
                | short iclassId) As StiDBItem
                | 
                |     Copys the SmarTeam object -and its children- to default Work directory,
                |     opens it into CATIA session and returns the corresponding
                |     CATIAStiDBItem.
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iobjectId
                |             This input corresponds to the Object ID of the required SmarTeam
                |             object. 
                |         iclassId
                |             This input corresponds to the Class ID of the required SmarTeam
                |             object. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved CATIAStiDBItem.
                |         
                |     Example:
                | 
                |           The following example retrieves a loaded document corresponding to a
                |           SmarTeam ID {Object ID, Class ID}.
                |          
                | 
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim iobjectId As long
                |          iobjectId = 963
                |          Dim iclassId As short
                |          iclassId = 57
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.BuildDocDBItemFromSmarTeamID iobjectId, iclassId

        :param int iobject_id:
        :param int iclass_id:
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_engine.BuildDocDBItemFromSmarTeamID(iobject_id, iclass_id))

    def build_file_db_item_from_smar_team_id(self, iobject_id: int, iclass_id: int) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func BuildFileDBItemFromSmarTeamID(long iobjectId,
                | short iclassId) As StiDBItem
                | 
                |     Copys the SmarTeam object -and its children- to default Work directory and
                |     returns the corresponding CATIAStiDBItem, Without opening the file into CATIA
                |     session.
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iobjectId
                |             This input corresponds to the Object ID of the required SmarTeam
                |             object. 
                |         iclassId
                |             This input corresponds to the Class ID of the required SmarTeam
                |             object. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved CATIAStiDBItem.
                |         
                |     Example:
                | 
                |           The following example retrieves a loaded document corresponding to a
                |           SmarTeam ID {Object ID, Class ID}.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim iobjectId As long
                |          iobjectId = 963
                |          Dim iclassId As short
                |          iclassId = 57
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.BuildFileDBItemFromSmarTeamID iobjectId, iclassId

        :param int iobject_id:
        :param int iclass_id:
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_engine.BuildFileDBItemFromSmarTeamID(iobject_id, iclass_id))

    def connect(self, i_user_login: str, i_user_password: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Connect(CATBSTR iUserLogin,
                | CATBSTR iUserPassword)
                | 
                |     Connects to SmarTeam Integration.
                |     This connection to SmarTeam Integration is equivalent to launch in CATIA
                |     the command SmarTeam/Connect.
                |     Note that this method is totally independent of the value returned by
                |     'UseGraphicalUI' and that the 'SmarTeam User Login' panel (dedicated connection
                |     panel) may be displayed.
                | 
                |     Parameters:
                | 
                |         iUserLogin
                |             This input corresponds to the Login name of the end user, who wants
                |             to connect to SmarTeam Integration. 
                |         iUserPassword
                |             This input corresponds to the associated Password of this end
                |             user.
                | 
                |             Note that when 'iUserLogin' is EMPTY, the 'SmarTeam User Login'
                |             panel is displayed and the end user has to login himself. Note that
                |             'iUserPassword' is taken into account if and only if 'iUserLogin' is NOT empty.
                |
                |     Example:
                | 
                |           ********** Connection With 'iUserLogin' & 'iUserPassword'
                |           **********
                |          
                |         The following example connects end user to SmarTeam database on
                |         StiEngine oStiEngine Without displaying
                |          'SmarTeam User Login' panel. The User Login is "xxx" and his
                |          associated Password "yyy".
                |          Note that User Login and Password should NOT be EMPTY. Otherwise the
                |          'SmarTeam User Login' panel will be displayed.
                |          If User Login or Password are NOT correct, the connection
                |          failed.
                |          
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim iUserLogin As CATBSTR
                |          iUserLogin = "xxx"
                |          Dim iUserPassword As CATBSTR
                |          iUserPassword = "yyy"
                |          oStiEngine.Connect iUserLogin,iUserPassword
                |
                |          ********** Connection Without 'iUserLogin' & 'iUserPassword'
                |          **********
                |          
                |         The following example connects end user to SmarTeam database on
                |         stiEngine oStiEngine With 'SmarTeam User Login' panel.
                |          The end user will have to type his Login and his Password in the
                |          dedicated panel.
                |          Note that if the User Login and his Password are specified, the
                |          'SmarTeam User Login' panel will NOT be displayed.
                |          If the end user only specifies his Login or if User Login and/or
                |          Password are NOT correct, the connection failed. 
                |          In these cases, the 'SmarTeam User Login' panel will NOT be
                |          displayed.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          oStiEngine.Connect "",""

        :param str i_user_login:
        :param str i_user_password:
        :rtype: None
        """
        return self.sti_engine.Connect(i_user_login, i_user_password)

    def disconnect(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Disconnect()
                | 
                |     Disconnects to SmarTeam Integration.
                |     This disconnection to SmarTeam Integration is equivalent to launch in CATIA
                |     the command SmarTeam/Disconnect.
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Example:
                | 
                |           The following example disconnects end user to SmarTeam database on
                |           StiEngine oStiEngine.
                |          
                | 
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          oStiEngine.Connect "",""
                |          (...)
                |          oStiEngine.Disconnect

        :rtype: None
        """
        return self.sti_engine.Disconnect()

    def get_smarteam_class_id(self, i_sti_db_item: StiDBItem) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSMARTEAMClassID(StiDBItem iStiDBItem) As short
                | 
                |     Returns the Class Identifier of a SmarTeam Integration Object
                |     CATIAStiDBItem -at least saved in SmarTeam.
                |     Note that the Class Identifier is unique for each Class defined in SmarTeam
                |     Data Model. This data is so linked to the current DataBase, that is to say With
                |     the SmarTeam Release (RXX).
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved Class Identifier of the
                |         CATIAStiDBItem. 
                |     Example:
                | 
                |           The following example returns in oClassId the Class Identifier of the
                |           CATIAStiDBItem oStiDBItem.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          ' Retrieve the Current Activated Product Document
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject(productDocument01)
                |          Dim oClassId As short
                |          oClassId = oStiEngine.GetSMARTEAMClassID(iStiDBItem)

        :param StiDBItem i_sti_db_item:
        :rtype: int
        """
        return self.sti_engine.GetSMARTEAMClassID(i_sti_db_item.com_object)

    def get_smarteam_object_id(self, i_sti_db_item: StiDBItem) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSMARTEAMObjectID(StiDBItem iStiDBItem) As long
                | 
                |     Returns the Object Identifier of a SmarTeam Integration Object
                |     CATIAStiDBItem -at least saved in SmarTeam.
                |     This data is linked to the current DataBase, that is to say to the SmarTeam
                |     Release (RXX).
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved Object Identifier of the
                |         CATIAStiDBItem.
                |
                |     Example:
                | 
                |           The following example returns in oObjectId the Object Identifier of
                |           the CATIAStiDBItem oStiDBItem.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          ' Retrieve the Current Activated Product Document
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject(productDocument01)
                |          Dim oObjectId As long
                |          oObjectId = oStiEngine.GetSMARTEAMObjectID(iStiDBItem)

        :param StiDBItem i_sti_db_item:
        :rtype: int
        """
        return self.sti_engine.GetSMARTEAMObjectID(i_sti_db_item.com_object)

    def get_sti_db_item_from_any_object(self, i_any_object: AnyObject) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStiDBItemFromAnyObject(AnyObject iAnyObject) As
                | StiDBItem
                | 
                |     Returns the SmarTeam Integration Object CATIAStiDBItem from an AnyObject
                |     object.
                |     This method is useful to convert whatever CATIA V5 Object to a
                |     CATIAStiDBItem.
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iAnyObject
                |             This input corresponds to a CATIA V5 Object. It must be a Document,
                |             a Product, a Part or a DrawingSheet. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved CATIAStiDBItem.
                |         
                |     Example:
                | 
                |           The following example returns in oStiDBItem the CATIAStiDBItem
                |           corresponding to the Document iDocument.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          ' Retrieve the Current Activated Product Document
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.GetStiDBItemFromAnyObject(productDocument01)

        :param AnyObject i_any_object:
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_engine.GetStiDBItemFromAnyObject(i_any_object.com_object))

    def get_sti_db_item_from_catbstr(self, i_full_path: str) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStiDBItemFromCATBSTR(CATBSTR iFullPath) As
                | StiDBItem
                | 
                |     Returns the SmarTeam Integration Object CATIAStiDBItem from a Full
                |     Path.
                |     This method is useful to convert a path to a CATIAStiDBItem, that is to say
                |     to create a SmarTeam Integration object. The programmer is then able to manage
                |     its lifecycle (that is to say to Save, Check In, Check Out, Release, New
                |     Release, ... it).
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     See also:
                |         CATIAStiDBItem 
                |     Parameters:
                | 
                |         iFullPath
                |             This input corresponds to the Full Path of the object to retrieve.
                |             
                | 
                |     Returns:
                |         This output corresponds to the retrieved CATIAStiDBItem.
                |         
                |     Example:
                | 
                |           The following example returns in oStiDBItem the CATIAStiDBItem
                |           corresponding to the full path.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim iFullPath As CATBSTR
                |          iFullPath = "E:/CATIAFiles/Engine.CATProduct"
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR(iFullPath)

        :param str i_full_path:
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_engine.GetStiDBItemFromCATBSTR(i_full_path))

    def get_team_pdmurl(self, i_sti_db_item: StiDBItem) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTeamPDMURL(StiDBItem iStiDBItem) As CATBSTR
                | 
                |     Returns the Team PDM URL of a CATIAStiDBItem.
                |     Note that the Team PDM URL has the following syntax:
                |     "TeamPDM://DBExtractor?CLASSID.EQ.www.
                |     AND.OBJECTID.EQ.zzz.AND.Vers.EQ.1"
                |     The only values which are modified from a SmarTeam object to an other are
                |     the numbers corresponding to the document "Class ID" (www) and "Object ID"
                |     (zzz).
                |     Note that this method is always executed With GUI. Indeed it returns a
                |     SmarTeam panel displaying the TEAM PDM URL. It is so totally independent of the
                |     value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem. 
                | 
                |     Returns:
                |         This output corresponds to the retrieved Team PDM URL of the
                |         CATIAStiDBItem.
                |
                |     Example:
                | 
                |           The following example returns the Team PDM URL from a
                |           CATIAStiDBItem.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim iobjectId As long
                |          iobjectId = 963
                |          Dim iclassId As short
                |          iclassId = 57
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.BuildFileDBItemFromSmarTeamID iobjectId, iclassId
                |          Dim oTeamPDMURL As CATBSTR
                |          oTeamPDMURL = oStiEngine.GetTeamPDMURL iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: str
        """
        return self.sti_engine.GetTeamPDMURL(i_sti_db_item.com_object)

    def is_connected(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsConnected() As boolean
                | 
                |     Returns if end user Is Connected to SmarTeam Integration (True) or not
                |     (False).
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     Example:
                | 
                |           The following example tests if end user is connected to SmarTeam
                |           Integration on StiEngine oStiEngine.
                |          If end user is not connected, this code sample allows her/him to
                |          connect to SmarTeam Integration by displaying the 'SmarTeam User Login'
                |          panel.
                |          
                | 
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oIsConnected As boolean
                |          oIsConnected = oStiEngine.IsConnected
                |          If Not oStiEngine.IsConnected() Then
                |            oStiEngine.Connect
                |          End If

        :rtype: bool
        """
        return self.sti_engine.IsConnected()

    def life_cycle_check_in(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleCheckIn(StiDBItem iStiDBItem)
                | 
                |     Checks the CATIAStiDBItem Into SmarTeam Check-In Vault.
                |     This LifeCycleCheckIn operation is equivalent to launch in CATIA the
                |     command SmarTeam/LifeCycle/CheckIn.
                |     2 cases: either the document is NEW (that is to say already saved in
                |     SmarTeam) or the document is being Modified (Checked-Out) and is removed back
                |     into the vault.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to Check-In.
                |
                |     Example:
                | 
                |           ********** LifeCycleCheckIn With GUI **********
                |          
                |         The following example checks the current activated document -associated
                |         to the CATIAStiDBItem oStiDBItem and
                |          already saved in SmarTeam -into the vault.
                |          
                |         Note that in the dedicated panel, the end user should choose to
                |         activate the following options 'Keep Local File' or 'Keep
                |         Checked-Out'.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckIn iStiDBItem
                |
                |          ********** LifeCycleCheckIn Without GUI **********
                |          
                |         The following example checks the current activated document -associated
                |         to the CATIAStiDBItem oStiDBItem and
                |          already saved in SmarTeam- into the vault.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckIn iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleCheckIn(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_check_in'
        # # vba_code = """
        # # Public Function life_cycle_check_in(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleCheckIn iStiDBItem
        # #     life_cycle_check_in = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_check_out(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleCheckOut(StiDBItem iStiDBItem)
                | 
                |     Checks Out Without Propagation the CATIAStiDBItem in
                |     SmarTeam.
                |     This LifeCycleCheckOut operation is equivalent to launch in CATIA the
                |     command SmarTeam/LifeCycle/CheckOut.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to Check-Out.
                |
                |     Example:
                | 
                |           ********** LifeCycleCheckOut With GUI **********
                |          
                |         The following example checks out from the vault the current activated
                |         document -associated to the CATIAStiDBItem oStiDBItem.
                |          Note that in the dedicated panel, the end user is able to realize the
                |          following action 'Propagate Operation' to select which children she/he also
                |          wants to Check-Out.
                |          She/he has also access to the SmarTeam panel option 'Do not get the
                |          file from vault'.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckOut iStiDBItem
                |
                |          **********  LifeCycleCheckOut Without GUI **********
                |          
                |         The following example Checks Out from the vault the current activated
                |         document -associated to the StiDBItem oStiDBItem.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckOut iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleCheckOut(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_check_out'
        # # vba_code = """
        # # Public Function life_cycle_check_out(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleCheckOut iStiDBItem
        # #     life_cycle_check_out = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_check_out_propagated(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleCheckOutPropagated(StiDBItem iStiDBItem)
                | 
                |     Checks Out With Propagation the CATIAStiDBItem in
                |     SMARTEAM.
                |     This LifeCycleCheckOutPropagated operation is equivalent to launch in CATIA
                |     the command SmarTeam/LifeCycle/CheckOut and then to specify in the associated
                |     SmarTeam panel 'Actions/Propagate Operation'.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to be Checked-Out.
                |
                |     Example:
                | 
                |           **********  LifeCycleCheckOutPropagated With GUI
                |           **********
                |          
                |         The following example Checks Out from the vault the current activated
                |         document -associated to the CATIAStiDBItem oStiDBItem
                |          AND its children.
                |          She/he has also access to the SmarTeam panel option 'Do not get the
                |          file from vault'.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckOutPropagated iStiDBItem
                |
                |          **********  LifeCycleCheckOutPropagated Without GUI
                |          **********
                |          
                |         The following example Checks Out from the vault the current activated
                |         document -associated to the StiDBItem oStiDBItem
                |          AND its children.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleCheckOutPropagated iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleCheckOutPropagated(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_check_out_propagated'
        # # vba_code = """
        # # Public Function life_cycle_check_out_propagated(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleCheckOutPropagated iStiDBItem
        # #     life_cycle_check_out_propagated = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_new_release(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleNewRelease(StiDBItem iStiDBItem)
                | 
                |     Enables a New Release Without Propagation for the CATIAStiDBItem in
                |     SmarTeam.
                |     This LifeCycleNewRelease operation to SmarTeam Integration is equivalent to
                |     launch in CATIA the command SmarTeam/LifeCycle/NewRelease.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to New Release.
                |
                |     Example:
                | 
                |           **********  LifeCycleNewRelease With GUI **********
                |          
                |         The following example makes a new copy of a Released document
                |         associated to the CATIAStiDBItem oStiDBItem
                |          that was moved into the Released vault. The resulting document is a
                |          new revision of the source document. 
                |          Note that in the dedicated panel,the end user is also able to realize
                |          the following action 'Propagate Operation' to select which
                |          children
                |          she/he also wants to Check-Out. She/he has also access to the SmarTeam
                |          panel option 'Do not get the file from vault'.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleNewRelease iStiDBItem
                |
                |          **********  LifeCycleNewRelease Without GUI
                |          **********
                |          
                |         The following example makes a new copy of a Released document
                |         associated to the CATIAStiDBItem oStiDBItem
                |          that was moved into the Released vault. The resulting document is a
                |          new revision of the source document. 
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleNewRelease iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleNewRelease(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_new_release'
        # # vba_code = """
        # # Public Function life_cycle_new_release(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleNewRelease iStiDBItem
        # #     life_cycle_new_release = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_new_release_propagated(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleNewReleasePropagated(StiDBItem iStiDBItem)
                | 
                |     Enables a NewRelease action With Propagation for the CATIAStiDBItem in
                |     SmarTeam.
                |     This LifeCycleNewReleasePropagated operation is equivalent to launch in
                |     CATIA the command SmarTeam/LifeCycle/NewRelease and then to specify in the
                |     associated SmarTeam panel 'Propagate Operation'.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to be New Released.
                |
                |     Example:
                | 
                |            ********** LifeCycleNewReleasePropagated With GUI
                |            **********
                |          
                |         The following example makes a new copy of the Released document
                |         associated to the CATIAStiDBItem oStiDBItem and of its
                |         children.
                |          This document was previously saved into the Released vault. The
                |          resulting document is a new revision of the source document.
                |          
                |          She/he has also access to the SmarTeam panel option 'Do not get the
                |          file from vault'.
                |
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleNewReleasePropagated iStiDBItem
                |
                |          ********** LifeCycleNewReleasePropagated Without GUI
                |          **********
                |          
                |         The following example makes a new copy of a Released document
                |         associated to the CATIAStiDBItem oStiDBItem and of its
                |         children.
                |          This document was previously saved into the Released vault. The
                |          resulting document is a new revision of the source document.
                |
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleNewReleasePropagated iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleNewReleasePropagated(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_new_release_propagated'
        # # vba_code = """
        # # Public Function life_cycle_new_release_propagated(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleNewReleasePropagated iStiDBItem
        # #     life_cycle_new_release_propagated = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_release(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleRelease(StiDBItem iStiDBItem)
                | 
                |     Releases the CATIAStiDBItem in SmarTeam Release Vault.
                |     This LifeCycleRelease operation is equivalent to launch in CATIA the
                |     command SmarTeam/LifeCycle/Release.
                |     3 cases: either the document is New (that is to say already saved in
                |     SmarTeam) or it is being Modified (Checked-Out or New Released) and is removed
                |     back into the vault or it is Checked-In and is moved from the Check-In vault to
                |     the Release one.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to Released.
                |
                |     Example:
                | 
                |           ********** LifeCycleRelease With GUI ********** 
                |          
                |         The following example releases the current activated document
                |         -associated to the CATIAStiDBItem oStiDBItem and
                |          already saved in SmarTeam- into the vault.
                |          
                |         Note that in the dedicated panel, the end user should choose to
                |         activate the following options 'Keep Local File' or 'Keep
                |         Checked-Out'.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current activated document
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleRelease iStiDBItem
                |
                |          ********** LifeCycleRelease Without GUI **********
                |          
                |         The following example moves the current activated document -associated
                |         to the CATIAStiDBItem oStiDBItem and
                |          already saved in SmarTeam -into the Released vault.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current activated document
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleRelease iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleRelease(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_release'
        # # vba_code = """
        # # Public Function life_cycle_release(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleRelease iStiDBItem
        # #     life_cycle_release = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def life_cycle_undo_check_out(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub LifeCycleUndoCheckOut(StiDBItem iStiDBItem)
                | 
                |     Cancels Check-Out operation on the CATIAStiDBItem in SmarTeam. So the
                |     programmer is able to retrieve the previous latest state (Checked-In or
                |     Released) of the CATIAStiDBItem.
                |     This LifeCycleUndoCheckOut operation is equivalent to launch in CATIA the
                |     command SmarTeam/LifeCycle/UndoCheckOut.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to be Undo
                |             Checked-Out. 
                | 
                |     Example:
                | 
                |           **********  LifeCycleUndoCheckOut With GUI
                |           **********
                |          
                |         The following example retrieves a copy of a document associated to the
                |         CATIAStiDBItem oStiDBItem
                |          in the previous latest state (Checked-In or
                |          Released).
                |          
                |         A CATIA panel is firstly displayed to warn the end user that it is
                |         strongly recommanded to confirm the file deletion when
                |         asked.
                |          If, the end user clicks "OK", a SmarTeam panel is then displayed "File
                |          '(...)/Work/CATPRD-XXXX.CATProduct' is referenced only by
                |          
                |          Object 'CATPRD-XXXX RevX.X', and will be deleted. Do you want to
                |          delete this file?" The end user had better accept.
                |          
                | 
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleUndoCheckOut iStiDBItem
                |
                |          **********  LifeCycleUndoCheckOut Without GUI
                |          **********
                |          
                |         The following example cancels the Check-Out of the document associated
                |         to the CATIAStiDBItem oStiDBItem 
                |          in the previous latest state (Checked-In or
                |          Released).
                |          
                |         By default, the Undo Check-Out operation is not propagated, i.e.
                |         available only for the current CATIAStiDBItem.
                |          
                | 
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          oStiEngine.LifeCycleUndoCheckOut iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.LifeCycleUndoCheckOut(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'life_cycle_undo_check_out'
        # # vba_code = """
        # # Public Function life_cycle_undo_check_out(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.LifeCycleUndoCheckOut iStiDBItem
        # #     life_cycle_undo_check_out = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def refresh_info(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RefreshInfo()
                | 
                |     Refreshes Information concerning all CATIA Documents in
                |     session.
                |     This RefreshInfo operation is equivalent to launch in CATIA the command
                |     SmarTeam/Tools/Refresh.
                |     Note that this method is always executed Without any GUI and is so totally
                |     independent of the value returned by 'UseGraphicalUI'.
                | 
                |     During this RefreshInfo operation, the following steps are
                |     executed:
                |         - Checking the document synchronization on disk, 
                |         - Updating internal info, 
                |         - Updating Read/Write status for valid documents, 
                |         - Updating icons, 
                |         - Sending error or warning message for not synchronized or removed
                |         documents if GUIs are activated. 
                | 
                |     Example:
                | 
                |           The following example refreshs the CATIA session:
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          oStiEngine.RefreshInfo

        :rtype: None
        """
        return self.sti_engine.RefreshInfo()

    def save(self, i_sti_db_item: StiDBItem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Save(StiDBItem iStiDBItem)
                | 
                |     Saves the CATIAStiDBItem in SmarTeam.
                |     This Save operation is equivalent to launch in CATIA the command
                |     SmarTeam/Save.
                |     Note that this method should be executed With GUI and is so totally
                |     dependent of the value returned by 'UseGraphicalUI'. The SmarTeam Integration
                |     Object (and its children) is(are) saved in the current Work -if NOT already
                |     saved on disc.
                | 
                |     Parameters:
                | 
                |         iStiDBItem
                |             This input corresponds to the CATIAStiDBItem to save.
                |
                |     Example:
                | 
                |           ********** Save With GUI **********
                |          
                |         Note that in the 'Projects Manager' panel, the end user should select
                |         the 'Project' in which she/he wants to save the corresponding
                |         file.
                |          If she/he selects one, then she/he can activate the option 'Link To
                |          Projects' and then 'Secured By' and to finish 'Propagate
                |          security'.
                |          She/he is also able to choose to activate the following option 'Add To
                |          Desktop'. 
                |          
                |         The following example saves in SmarTeam the CATIAStiDBItem oStiDBItem
                |         With GUI.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If Not bIsActive Then
                |            oStiEngine.UseGraphicalUI = True
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject(productDocument01)
                |          oStiEngine.Save iStiDBItem 
                |
                |          ********** Save Without GUI **********
                |          
                |         By Default, the SmarTeam Integration Object (and its children) is(are)
                |         saved in the current Work -if NOT already saved on disc,
                |         
                |          NOT linked With any Project and NOT Added to Desktop.
                |          
                |         The following example saves in SmarTeam the CATIAStiDBItem oStiDBItem
                |         Without GUI.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim bIsActive As boolean
                |          bIsActive = oStiEngine.UseGraphicalUI
                |          If bIsActive Then
                |            oStiEngine.UseGraphicalUI = False 
                |          End If
                |          ' Retrieve the Current Activated Product
                |          Dim productDocument01 As Document
                |          Set productDocument01 = CATIA.ActiveDocument
                |          ' Retrieve the StiDBItem from the Document
                |          Dim iStiDBItem As StiDBItem
                |          Set iStiDBItem = oStiEngine.GetStiDBItemFromAnyObject( productDocument01 )
                |          ' Save the Product
                |          oStiEngine.Save iStiDBItem

        :param StiDBItem i_sti_db_item:
        :rtype: None
        """
        return self.sti_engine.Save(i_sti_db_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'save'
        # # vba_code = """
        # # Public Function save(sti_engine)
        # #     Dim iStiDBItem (2)
        # #     sti_engine.Save iStiDBItem
        # #     save = iStiDBItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StiEngine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCurveSmooth(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCurveSmooth
                | 
                | Represents the hybrid shape curve smoothing operation feature.
                | Role: To access the data of the curve smoothing operation.of the hybrid shape
                | curve parameter object. This data includes:
                | 
                |     The curve to smooth
                |     The support (if exist )
                |     The tangent tolerance value (threshold)
                |     The curvature tolerance value (threshold)
                |     The info if curvature threshold is activated
                |     The maximum deviation accepted
                |     The info if maxcimum deviation is activated
                |     The fixed points
                |     The fixed segments
                |     The info if topology simplification is activated
                | 
                | Use the HybridShapeFactory.AddNewCurveSmooth to create a HybridShapeCurveSmooth
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_curve_smooth = com_object

    @property
    def correction_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CorrectionMode() As long
                | 
                |     Returns or sets the correction mode (threshold, point, tangency or
                |     curvature) applied to the smoothed curve.
                |     Legal values:
                | 
                |     0
                |         CATGSMCSCorrectionMode_Threshold. no continuity 
                |     1
                |         CATGSMCSCorrectionMode_Point. continuity in point
                |         (C0).
                |     2
                |         CATGSMCSCorrectionMode_Tangency. continuity in tangency
                |         (C1).
                |     3
                |         CATGSMCSCorrectionMode_Curvature. continuity in curvature
                |         (C2).
                | 
                | Example:
                |     This example retrieves in oMode the correction mode for the
                |     hybShpCurveSmooth hybrid shape feature.
                | 
                |      oMode = hybShpCurveSmooth.CorrectionMode

        :rtype: int
        """

        return self.hybrid_shape_curve_smooth.CorrectionMode

    @correction_mode.setter
    def correction_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_smooth.CorrectionMode = value

    @property
    def curvature_threshold(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurvatureThreshold() As double
                | 
                |     Returns or sets the CurvatureThreshold.
                | 
                |     Example: This example retrieves the CurvatureThreshold of the
                |     hybShpCurveSmooth in CurvatureThH.
                | 
                |      Dim CurvatureThH as double
                |      CurvatureThH = hybShpCurvePar.CurvatureThreshold

        :rtype: float
        """

        return self.hybrid_shape_curve_smooth.CurvatureThreshold

    @curvature_threshold.setter
    def curvature_threshold(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_curve_smooth.CurvatureThreshold = value

    @property
    def curvature_threshold_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurvatureThresholdActivity() As boolean
                | 
                |     Returns or sets the CurvatureThresholdActivity.
                | 
                |     Example: This example retrieves the CurvatureThresholdActivity of the
                |     hybShpCurveSmooth in CurvatureActivity .
                | 
                |      Dim CurvatureActivity as boolean 
                |      CurvatureActivity = hybShpCurvePar.CurvatureThresholdActivity

        :rtype: bool
        """

        return self.hybrid_shape_curve_smooth.CurvatureThresholdActivity

    @curvature_threshold_activity.setter
    def curvature_threshold_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_smooth.CurvatureThresholdActivity = value

    @property
    def curve_to_smooth(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurveToSmooth() As Reference
                | 
                |     Returns or sets the curve to smooth.
                | 
                |     Example: This example retrieves the curve to smooth object of the
                |     hybShpCurveSmooth in Curve.
                | 
                |      Dim Curve as CATIAReference 
                |      Curve  = hybShpCurvePar.CurveToSmooth

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_smooth.CurveToSmooth)

    @curve_to_smooth.setter
    def curve_to_smooth(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_curve_smooth.CurveToSmooth = reference_curve.com_object

    @property
    def end_extremity_continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndExtremityContinuity() As long
                | 
                |     Returns or sets the continuity condition (curvature, tangency or point)
                |     applied to the smoothed curve with regard to the input curve at the end
                |     extremity of the input curve.
                |     Legal values:
                | 
                |     0
                |         CATGSMContinuity_Point. continuity in point (C0). 
                |     1
                |         CATGSMContinuity_Tangency. continuity in tangency
                |         (C1).
                |     2
                |         CATGSMContinuity_Curvature. continuity in curvature
                |         (C2).
                | 
                | Example:
                |     This example retrieves in oContinuity the continuity at the end extremity
                |     for the hybShpCurveSmooth hybrid shape feature.
                | 
                |      oContinuity = hybShpCurveSmooth.EndExtremityContinuity

        :rtype: int
        """

        return self.hybrid_shape_curve_smooth.EndExtremityContinuity

    @end_extremity_continuity.setter
    def end_extremity_continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_smooth.EndExtremityContinuity = value

    @property
    def maximum_deviation(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDeviation() As Length (Read Only)
                | 
                |     Returns the MaximumDeviation.
                | 
                |     Example: This example retrieves the MaximumDeviation of the
                |     hybShpCurveSmooth in MaximumDeviationVal.
                | 
                |      Dim MaximumDeviationVal as CATIALength
                |      MaximumDeviationVal  = hybShpCurvePar.MaximumDeviation

        :rtype: Length
        """

        return Length(self.hybrid_shape_curve_smooth.MaximumDeviation)

    @property
    def maximum_deviation_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDeviationActivity() As boolean
                | 
                |     Returns or sets the MaximumDeviationActivity.
                | 
                |     Example: This example retrieves the MaximumDeviationActivity of the
                |     hybShpCurveSmooth in MaxActivity .
                | 
                |      Dim MaxActivity as boolean
                |      MaxActivity  = hybShpCurvePar.MaximumDeviationActivity

        :rtype: bool
        """

        return self.hybrid_shape_curve_smooth.MaximumDeviationActivity

    @maximum_deviation_activity.setter
    def maximum_deviation_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_smooth.MaximumDeviationActivity = value

    @property
    def start_extremity_continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartExtremityContinuity() As long
                | 
                |     Returns or sets the continuity condition (curvature, tangency or point)
                |     applied to the smoothed curve with regard to the input curve at the start
                |     extremity of the input curve.
                |     Legal values:
                | 
                |     0
                |         CATGSMContinuity_Point. continuity in point (C0). 
                |     1
                |         CATGSMContinuity_Tangency. continuity in tangency
                |         (C1).
                |     2
                |         CATGSMContinuity_Curvature. continuity in curvature
                |         (C2).
                | 
                | Example:
                |     This example retrieves in oContinuity the continuity at the start extremity
                |     for the hybShpCurveSmooth hybrid shape feature.
                | 
                |      oContinuity = hybShpCurveSmooth.StartExtremityContinuity

        :rtype: int
        """

        return self.hybrid_shape_curve_smooth.StartExtremityContinuity

    @start_extremity_continuity.setter
    def start_extremity_continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_smooth.StartExtremityContinuity = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support of the curve.
                |     if Suppport == nothing no support associated to the curve
                | 
                |     Example: This example retrieves the support of curve to smooth object of
                |     the hybShpCurveSmooth in Support.
                | 
                |      Dim Support  as CATIAReference 
                |      Support   = ybShpCurveSmooth.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_smooth.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_curve_smooth.Support = reference_support.com_object

    @property
    def tangency_threshold(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TangencyThreshold() As Angle (Read Only)
                | 
                |     Returns the TangencyThreshold.
                | 
                |     Example: This example retrieves the curve to smooth object of the
                |     hybShpCurveSmooth in AngleThH.
                | 
                |      Dim Curve as CATIAAngle  
                |      AngleThH  = ybShpCurveSmooth.TangencyThreshold

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_curve_smooth.TangencyThreshold)

    @property
    def topology_simplification_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TopologySimplificationActivity() As boolean
                | 
                |     Returns or sets the TopologySimplificationActivity.
                | 
                |     Example: This example retrieves the TopologySimplificationActivity of the
                |     hybShpCurveSmooth in TopSimplifyAct.
                | 
                |      Dim TopSimplifyAct as boolean 
                |      TopSimplifyAct  = hybShpCurvePar.TogologySimplificationActivity 
                |      
                | 
                |     Methods
                | 
                | o Sub AddFrozenCurveSegment(Reference iCurve)
                | 
                |     Adds a frozen curve to the hybrid shape curve smooth feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iCurve
                |             The curve to be added to the hybrid shape curve smooth feature
                |             object. 
                | 
                |     Example:
                |         The following example adds the iCurve curve to the hybShpCurveSmooth
                |         object.
                | 
                |          hybShpCurveSmooth.AddFrozenCurveSegment iCurve
                |          
                | 
                | o Sub AddFrozenPoint(Reference iPoint)
                | 
                |     Adds a frozen points to the hybrid shape curve smooth feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             The frozen point to be added to the hybrid shape curve smooth
                |             feature object. 
                | 
                |     Example:
                |         The following example adds the iPoint frozen point to the
                |         hybShpCurveSmooth object.
                | 
                |          hybShpCurveSmooth.AddFrozenPoint iPoint
                |          
                | 
                | o Func GetFrozenCurveSegment(long iPos) As Reference
                | 
                |     Retrieves the Frozen Curve Segment at specified position in the hybrid
                |     shape curve smooth object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the Frozen Curve Segment to retrieve.
                |             
                | 
                |     Example:
                |         The following example gets the oCurve Frozen Curve Segment of the
                |         hybShpCurveSmooth object at the position iPos.
                | 
                |          Dim oCurve As Reference
                |          Set oCurve = hybShpCurveSmooth.GetFrozenCurveSegment (iPos).
                |          
                | 
                | o Func GetFrozenCurveSegmentsSize() As long
                | 
                |     Returns the number of frozen curve segments in the curve smooth
                |     object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of frozen curve segments in the curve
                |             smooth.
                | 
                |             Example:
                |                 This example retrieves the number of frozen curve segments. in
                |                 the hybShpCurveSmooth hybrid shape curve
                |                 smooth.
                | 
                |                  Dim oSize As  long
                |                  oSize = hybShpCurveSmooth.GetFrozenCurveSegmentsSize
                |                  
                | 
                | o Func GetFrozenPoint(long iPos) As Reference
                | 
                |     Retrieves the Frozen Point at specified position in the hybrid shape curve
                |     smooth object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position of the Frozen Point to retrieve. 
                | 
                |     Example:
                |         The following example gets the oPoint Frozen Point of the
                |         hybShpCurveSmooth object at the position iPos.
                | 
                |          Dim oPoint As Reference
                |          Set oPoint = hybShpCurveSmooth.GetFrozenPoint (iPos).
                |          
                | 
                | o Func GetFrozenPointsSize() As long
                | 
                |     Returns the number of Frozen Points in the curve smooth
                |     object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of Frozen Points in the curve smooth.
                | 
                |             Example:
                |                 This example retrieves the number of Frozen Points. in the
                |                 hybShpCurveSmooth hybrid shape curve smooth.
                | 
                |                  Dim oSize As  long
                |                  oSize = hybShpCurveSmooth.GetFrozenPointsSize
                |                  
                | 
                | o Sub RemoveAllFrozenCurveSegments()
                | 
                |     Removes all Frozen Curve Segment of the hybrid shape curve smooth object.
                |     
                | 
                | Example:
                |     The following example removes all Frozen Curve Segments of the
                |     hybShpCurveSmooth object.
                | 
                |      hybShpCurveSmooth.RemoveAllFrozenCurveSegments
                |      
                | 
                | o Sub RemoveAllFrozenPoints()
                | 
                |     Removes all Frozen Points of the hybrid shape curve smooth object.
                |     
                | 
                | Example:
                |     The following example removes all Frozen Points of the hybShpCurveSmooth
                |     object.
                | 
                |      hybShpCurveSmooth.RemoveAllFrozenPoints
                |      
                | 
                | o Sub RemoveFrozenCurveSegment(Reference iCurve)
                | 
                |     Removes Frozen Curve Segment from the list of Forzen curves in hybrid shape
                |     curve smooth object.
                | 
                |     Parameters:
                | 
                |         iCurve
                |             The Frozen Curve Segment to remove. 
                | 
                |     Example:
                |         The following example removes the Frozen Curve Segment from the
                |         hybShpCurveSmooth object.
                | 
                |          hybShpCurveSmooth.RemoveFrozenCurveSegment iCurve.
                |          
                | 
                | o Sub RemoveFrozenPoint(Reference iPoint)
                | 
                |     Removes Frozen Point from the list of frozen points in hybrid shape curve
                |     smooth object.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             The Frozen Point to remove. 
                | 
                |     Example:
                |         The following example removes the Frozen Point from the
                |         hybShpCurveSmooth object.
                | 
                |          hybShpCurveSmooth.RemoveFrozenPoint iPoint.
                |          
                | 
                | o Sub SetMaximumDeviation(double iMaxDeviation)
                | 
                |     Sets the maximum deviation.
                | 
                |     Parameters:
                | 
                |         iMaxDeviation
                |             The maximium deviation
                | 
                | o Sub SetTangencyThreshold(double iTangencyThreshold)
                | 
                |     Sets the tangency threshold.
                | 
                |     Parameters:
                | 
                |         iTangencyThreshold
                |             The tangency threshold

        :rtype: bool
        """

        return self.hybrid_shape_curve_smooth.TopologySimplificationActivity

    @topology_simplification_activity.setter
    def topology_simplification_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_smooth.TopologySimplificationActivity = value

    def add_frozen_curve_segment(self, i_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFrozenCurveSegment(Reference iCurve)
                |
                |     Adds a frozen curve to the hybrid shape curve smooth feature
                |     object.
                |
                |     Parameters:
                |
                |         iCurve
                |             The curve to be added to the hybrid shape curve smooth feature
                |             object.
                |
                |     Example:
                |         The following example adds the iCurve curve to the hybShpCurveSmooth
                |         object.
                |
                |          hybShpCurveSmooth.AddFrozenCurveSegment iCurve

        :param Reference i_curve:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.AddFrozenCurveSegment(i_curve.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_frozen_curve_segment'
        # # vba_code = """
        # # Public Function add_frozen_curve_segment(hybrid_shape_curve_smooth)
        # #     Dim iCurve (2)
        # #     hybrid_shape_curve_smooth.AddFrozenCurveSegment iCurve
        # #     add_frozen_curve_segment = iCurve
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_frozen_point(self, i_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFrozenPoint(Reference iPoint)
                |
                |     Adds a frozen points to the hybrid shape curve smooth feature
                |     object.
                |
                |     Parameters:
                |
                |         iPoint
                |             The frozen point to be added to the hybrid shape curve smooth
                |             feature object.
                |
                |     Example:
                |         The following example adds the iPoint frozen point to the
                |         hybShpCurveSmooth object.
                |
                |          hybShpCurveSmooth.AddFrozenPoint iPoint

        :param Reference i_point:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.AddFrozenPoint(i_point.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_frozen_point'
        # # vba_code = """
        # # Public Function add_frozen_point(hybrid_shape_curve_smooth)
        # #     Dim iPoint (2)
        # #     hybrid_shape_curve_smooth.AddFrozenPoint iPoint
        # #     add_frozen_point = iPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_frozen_curve_segment(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFrozenCurveSegment(long iPos) As Reference
                |
                |     Retrieves the Frozen Curve Segment at specified position in the hybrid
                |     shape curve smooth object.
                |
                |     Parameters:
                |
                |         iPos
                |             The position of the Frozen Curve Segment to retrieve.
                |
                |
                |     Example:
                |         The following example gets the oCurve Frozen Curve Segment of the
                |         hybShpCurveSmooth object at the position iPos.
                |
                |          Dim oCurve As Reference
                |          Set oCurve = hybShpCurveSmooth.GetFrozenCurveSegment (iPos).

        :param int i_pos:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_curve_smooth.GetFrozenCurveSegment(i_pos))

    def get_frozen_curve_segments_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFrozenCurveSegmentsSize() As long
                |
                |     Returns the number of frozen curve segments in the curve smooth
                |     object.
                |
                |     Parameters:
                |
                |         oSize
                |             Number of frozen curve segments in the curve
                |             smooth.
                |
                |             Example:
                |                 This example retrieves the number of frozen curve segments. in
                |                 the hybShpCurveSmooth hybrid shape curve
                |                 smooth.
                |
                |                  Dim oSize As  long
                |                  oSize = hybShpCurveSmooth.GetFrozenCurveSegmentsSize

        :rtype: int
        """
        return self.hybrid_shape_curve_smooth.GetFrozenCurveSegmentsSize()

    def get_frozen_point(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFrozenPoint(long iPos) As Reference
                |
                |     Retrieves the Frozen Point at specified position in the hybrid shape curve
                |     smooth object.
                |
                |     Parameters:
                |
                |         iPos
                |             The position of the Frozen Point to retrieve.
                |
                |     Example:
                |         The following example gets the oPoint Frozen Point of the
                |         hybShpCurveSmooth object at the position iPos.
                |
                |          Dim oPoint As Reference
                |          Set oPoint = hybShpCurveSmooth.GetFrozenPoint (iPos).

        :param int i_pos:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_curve_smooth.GetFrozenPoint(i_pos))

    def get_frozen_points_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFrozenPointsSize() As long
                |
                |     Returns the number of Frozen Points in the curve smooth
                |     object.
                |
                |     Parameters:
                |
                |         oSize
                |             Number of Frozen Points in the curve smooth.
                |
                |             Example:
                |                 This example retrieves the number of Frozen Points. in the
                |                 hybShpCurveSmooth hybrid shape curve smooth.
                |
                |                  Dim oSize As  long
                |                  oSize = hybShpCurveSmooth.GetFrozenPointsSize

        :rtype: int
        """
        return self.hybrid_shape_curve_smooth.GetFrozenPointsSize()

    def remove_all_frozen_curve_segments(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllFrozenCurveSegments()
                |
                |     Removes all Frozen Curve Segment of the hybrid shape curve smooth object.
                |
                |
                | Example:
                |     The following example removes all Frozen Curve Segments of the
                |     hybShpCurveSmooth object.
                |
                |      hybShpCurveSmooth.RemoveAllFrozenCurveSegments

        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.RemoveAllFrozenCurveSegments()

    def remove_all_frozen_points(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllFrozenPoints()
                |
                |     Removes all Frozen Points of the hybrid shape curve smooth object.
                |
                |
                | Example:
                |     The following example removes all Frozen Points of the hybShpCurveSmooth
                |     object.
                |
                |      hybShpCurveSmooth.RemoveAllFrozenPoints

        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.RemoveAllFrozenPoints()

    def remove_frozen_curve_segment(self, i_curve: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFrozenCurveSegment(Reference iCurve)
                |
                |     Removes Frozen Curve Segment from the list of Forzen curves in hybrid shape
                |     curve smooth object.
                |
                |     Parameters:
                |
                |         iCurve
                |             The Frozen Curve Segment to remove.
                |
                |     Example:
                |         The following example removes the Frozen Curve Segment from the
                |         hybShpCurveSmooth object.
                |
                |          hybShpCurveSmooth.RemoveFrozenCurveSegment iCurve.

        :param Reference i_curve:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.RemoveFrozenCurveSegment(i_curve.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_frozen_curve_segment'
        # # vba_code = """
        # # Public Function remove_frozen_curve_segment(hybrid_shape_curve_smooth)
        # #     Dim iCurve (2)
        # #     hybrid_shape_curve_smooth.RemoveFrozenCurveSegment iCurve
        # #     remove_frozen_curve_segment = iCurve
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_frozen_point(self, i_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFrozenPoint(Reference iPoint)
                |
                |     Removes Frozen Point from the list of frozen points in hybrid shape curve
                |     smooth object.
                |
                |     Parameters:
                |
                |         iPoint
                |             The Frozen Point to remove.
                |
                |     Example:
                |         The following example removes the Frozen Point from the
                |         hybShpCurveSmooth object.
                |
                |          hybShpCurveSmooth.RemoveFrozenPoint iPoint.

        :param Reference i_point:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.RemoveFrozenPoint(i_point.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_frozen_point'
        # # vba_code = """
        # # Public Function remove_frozen_point(hybrid_shape_curve_smooth)
        # #     Dim iPoint (2)
        # #     hybrid_shape_curve_smooth.RemoveFrozenPoint iPoint
        # #     remove_frozen_point = iPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_maximum_deviation(self, i_max_deviation: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMaximumDeviation(double iMaxDeviation)
                |
                |     Sets the maximum deviation.
                |
                |     Parameters:
                |
                |         iMaxDeviation
                |             The maximium deviation

        :param float i_max_deviation:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.SetMaximumDeviation(i_max_deviation)

    def set_tangency_threshold(self, i_tangency_threshold: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTangencyThreshold(double iTangencyThreshold)
                |
                |     Sets the tangency threshold.
                |
                |     Parameters:
                |
                |         iTangencyThreshold
                |             The tangency threshold

        :param float i_tangency_threshold:
        :rtype: None
        """
        return self.hybrid_shape_curve_smooth.SetTangencyThreshold(i_tangency_threshold)

    def __repr__(self):
        return f'HybridShapeCurveSmooth(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Activities(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Activities
                | 
                | The collection of activities related to the current activity.
                | 
                | It respectively manages the children hierarchy, the downstream control flow,
                | the uptream control flow, the downstream product flow or the upstream product
                | flow.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Activity)
        self.activities = com_object

    def add(self, i_activity: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add(Activity iActivity)
                | 
                |     This method adds the specified activity as a precedence
                |     constraint
                | 
                |     Parameters:
                | 
                |         iActivity
                |             The activity Handle

        :param Activity i_activity:
        :rtype: None
        """
        return self.activities.Add(i_activity.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add'
        # # vba_code = """
        # # Public Function add(activities)
        # #     Dim iActivity (2)
        # #     activities.Add iActivity
        # #     add = iActivity
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index: cat_variant) -> Activity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Activity
                | 
                |     This method gets the specified activity on the current activities
                |     management.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The activity identifier 
                | 
                |     Returns:
                |         oActivity The activity

        :param cat_variant i_index:
        :rtype: Activity
        """
        return Activity(self.activities.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     This method removes the specified activity on the current activities
                |     management.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The activity identifier

        :param cat_variant i_index:
        :rtype: None
        """
        return self.activities.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(activities)
        # #     Dim iIndex (2)
        # #     activities.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Activities(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.part_comp import PartComp
from pycatia.system_interfaces.collection import Collection


class PartComps(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     PartComps
                | 
                | Interface to access a CATIAPartComps
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=PartComp)
        self.part_comps = com_object

    @property
    def added_material_percentage(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AddedMaterialPercentage() As double (Read Only)
                | 
                |     Returns the added material percentage.

        :rtype: float
        """

        return self.part_comps.AddedMaterialPercentage

    @property
    def added_material_volume(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AddedMaterialVolume() As double (Read Only)
                | 
                |     Returns the added material volume.

        :rtype: float
        """

        return self.part_comps.AddedMaterialVolume

    @property
    def removed_material_percentage(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RemovedMaterialPercentage() As double (Read Only)
                | 
                |     Returns the removed material percentage.

        :rtype: float
        """

        return self.part_comps.RemovedMaterialPercentage

    @property
    def removed_material_volume(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RemovedMaterialVolume() As double (Read Only)
                | 
                |     Returns the removed material volume.

        :rtype: float
        """

        return self.part_comps.RemovedMaterialVolume

    def add(
            self,
            i_product1: Product,
            i_product2: Product,
            i_comp_accuracy: float,
            i_disp_accuracy: float,
            i_computation_type: int
    ) -> PartComp:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProduct1,
                | Product iProduct2,
                | double iCompAccuracy,
                | double iDispAccuracy,
                | long iComputationType) As PartComp
                | 
                |     Computes a new comparison between products. Documents created are added to
                |     the documents in the session. Document containing the added material is called
                |     AddedMaterial.3dmap. Document containing the removed material is called
                |     RemovedMaterial.3dmap. Document containing the changed material is called
                |     ChangedMaterial.3dmap. If the document are meant to be kept they must be
                |     renamed, otherwise they should be deleted. Document lifecyle must be managed
                |     either with SaveAs or Close.
                | 
                |     Parameters:
                | 
                |         iCompAccuracy
                |             Accuracy of the 3dmaps for the computation. 
                |         iDispAccuracy
                |             Accuracy of the displayed 3dmaps. 
                |         iComputationType
                |             0 : Added with position taken into account
                |             1 : Removed with position
                |             2 : Added + Removed with positions
                |             3 : Added without position
                |             4 : Removed without position
                |             5 : Added + Removed without positions
                | 
                |     Returns:
                |         Created PartComp 
                |     Example:
                | 
                |           The following example computes a comparison between two
                |           products:
                |          
                | 
                |          Dim newPartComp As PartComp
                |          Set newPartComp = PartComps.Add(product1, product2, 5.0, 5.0, 2)
                |          Dim documents1 As Documents
                |          Set documents1 = CATIA.Documents
                |          Dim document1 As Document
                |          Set document1 = documents1.Item("AddedMaterial.3dmap")

        :param Product i_product1:
        :param Product i_product2:
        :param float i_comp_accuracy:
        :param float i_disp_accuracy:
        :param int i_computation_type:
        :rtype: PartComp
        """
        return PartComp(
            self.part_comps.Add(
                i_product1.com_object,
                i_product2.com_object,
                i_comp_accuracy,
                i_disp_accuracy,
                i_computation_type
            )
        )

    def __repr__(self):
        return f'PartComps(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ParameterProfiles(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ParameterProfiles
                | 
                | Interface to manage an user-defined applicative parameter
                | profile.
                | 
                | Role: This interface allows the end-user to handle Applicative parameter
                | profiles attributes. To create them, please refer to
                | ParameterProfilesFactory.
                | Applicative profiles are defined using a Feature Dictionary Editor application.
                | The name of the attributes don't change after the CATFct file has been defined.
                | End-user must know what the name of the attributes are.
                | 
                | To get a handle on the robot, the product must be the assembly node
                | representing the robot (the one with a robot icon).
                | 
                | The following code can be used to retrieve a handle on a
                | profile
                | 
                |    'current document is a product
                |    'the root product is a robot
                | 
                |    'retrieving the root product
                |    Dim MyProduct As Product
                |    Set MyProduct = CATIA.ActiveDocument.Product
                | 
                |    'retrieving the handle
                |    Dim MyProfileFactory As ParameterProfilesFactory
                |    Set MyProfileFactory = MyProduct.GetTechnologicalObject("ParameterProfilesFactory")
                |    ...
                |    'retrieving the list of profiles as an array
                |    Dim MyListOfProfiles() As ParameterProfiles
                |    MyProfileFactory.GetAllProfileInstances(MyListOfProfiles)
                | 
                |    'loop for each profile to get the name
                |    Dim MyCurrentProfile as ParameterProfiles
                |    Dim MyCurrentProfileName
                |    For Each MyCurrentProfile In MyListOfProfiles
                |       MyCurrentProfileName.GetName(MyCurrentProfileName)
                |    Next
                |
                | ParameterProfilesFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.parameter_profiles = com_object

    def get_attribute_value(self, i_attribute_name: str, o_encapsulated_attribute_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAttributeValue(CATBSTR iAttributeName,
                | CATBSTR oEncapsulatedAttributeValue)
                | 
                |     Gets the attribute value for the attribute mentioned
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Name of the attribute for which the value has to be set (input)
                |             
                |         oEncapsulatedAttributeValue
                |             Value of the attribute encapsulated as a CATBSTR string (output)
                |
                |     Example:
                |
                |            ' declaration of handle for the profile
                |            Dim MyProfile As ParameterProfiles
                | 
                |            ' valuation 
                |            Set MyProfile= ...
                | 
                |            ' declaration of variable for name
                |            Dim AttributeName
                |            Dim AttributeValue
                | 
                |            ' valuation based on user inputs
                |            AttributeName = "MyAttributeName"  'example
                | 
                |            ' getting the attribute value 
                |            MyProfile.GetAttributeValue(AttributeName,AttributeValue)

        :param str i_attribute_name:
        :param str o_encapsulated_attribute_value:
        :rtype: None
        """
        return self.parameter_profiles.GetAttributeValue(i_attribute_name, o_encapsulated_attribute_value)

    def get_name(self, o_instance_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oInstanceName)
                | 
                |     Gets the new name for the Profile instance
                | 
                |     Parameters:
                | 
                |         oInstanceName
                |             Name of the Profile instance (output) 
                | 
                |     Example:
                |
                |            ' declaration of handle for the profile
                |            Dim MyProfile As ParameterProfiles
                | 
                |            ' valuation 
                |            Set MyProfile= ...
                | 
                |            ' declaration of variable for name
                |            Dim InstanceName
                | 
                |            ' setting the name 
                |            MyProfile.GetName(InstanceName)

        :param str o_instance_name:
        :rtype: None
        """
        return self.parameter_profiles.GetName(o_instance_name)

    def set_attribute_value(self, i_attribute_name: str, i_encapsulated_attribute_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttributeValue(CATBSTR iAttributeName,
                | CATBSTR iEncapsulatedAttributeValue)
                | 
                |     Sets a new attribute value for the attribute mentioned
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Name of the attribute for which the value has to be set (input)
                |             
                |         iEncapsulatedAttributeValue
                |             Value of the attribute encapsulated as a CATBSTR string (input)
                |
                |     Example:
                |
                |            ' declaration of handle for the profile
                |            Dim MyProfile As ParameterProfiles
                | 
                |            ' valuation 
                |            Set MyProfile= ...
                | 
                |            ' declaration of variable for name
                |            Dim AttributeName
                |            Dim AttributeValue
                | 
                |            ' valuation based on user inputs
                |            AttributeName = "MyAttributeName"  'example
                |            AttributeValue= "MyAttributeValue" 'example
                | 
                |            ' setting the attribute value 
                |            MyProfile.SetAttributeValue(AttributeName,AttributeValue)

        :param str i_attribute_name:
        :param str i_encapsulated_attribute_value:
        :rtype: None
        """
        return self.parameter_profiles.SetAttributeValue(i_attribute_name, i_encapsulated_attribute_value)

    def set_name(self, i_new_instance_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iNewInstanceName)
                | 
                |     Sets a new name for the Profile instance
                | 
                |     Parameters:
                | 
                |         iNewInstanceName
                |             New name of the Profile instance (input) 
                | 
                |     Example:
                |
                |            ' declaration of handle for the profile
                |            Dim MyProfile As ParameterProfiles
                | 
                |            ' valuation 
                |            Set MyProfile= ...
                | 
                |            ' declaration of variable for name
                |            Dim InstanceName
                |            ' valuation 
                |            InstanceName = "MyInstanceName.2" 'example
                | 
                |            ' setting the name 
                |            MyProfile.SetName(InstanceName)

        :param str i_new_instance_name:
        :rtype: None
        """
        return self.parameter_profiles.SetName(i_new_instance_name)

    def __repr__(self):
        return f'ParameterProfiles(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_manager import AnalysisManager
from pycatia.system_interfaces.any_object import AnyObject


class AnalysisExport(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisExport
                | 
                | The interface to access a CATIAAnalysisExport
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_export = com_object

    def export(self, i_full_path: str, i_type: str, i_occurrences: tuple, i_manager: AnalysisManager) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Export(CATBSTR iFullPath,
                | CATBSTR iType,
                | CATSafeArrayVariant iOccurrences,
                | AnalysisManager iManager)
                | 
                |     Export computed loads/displacements as a CATAnalysisExport
                |     file.
                | 
                |     Parameters:
                | 
                |         iFullPath
                |             The full path of the file.
                |             (Example:
                |             "E:\\tmp\\ExportedLoads\\CATAnalysisExport").
                |         iType
                |             The type of data to be exported: "ComputedLoads" or
                |             "Displacements".
                |         iOccurrences
                |             The list of occurrences to be exported.
                |         iManager
                |             The analysis model for which the data will be
                |             exported.
                |             (Only revelant for assembly of analysis.)

        :param str i_full_path:
        :param str i_type:
        :param tuple i_occurrences:
        :param AnalysisManager i_manager:
        :rtype: None
        """
        return self.analysis_export.Export(i_full_path, i_type, i_occurrences, i_manager.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export'
        # # vba_code = """
        # # Public Function export(analysis_export)
        # #     Dim iFullPath (2)
        # #     analysis_export.Export iFullPath
        # #     export = iFullPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisExport(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class IgpOlpSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         IgpOlpSettingAtt
                | 
                | Represents the Offline Programming setting controller object.
                | Role: The Offline Programming setting controller object deals with the setting
                | attributes displayed in the IGRIP/Offline Programming property page. To access
                | this property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click IGRIP
                |     Right scroll to display the property pages titles until you get Offline
                |     Programming
                |     Click Offline Programming
                | 
                | The Offline Programming setting controller object can be retrieved as an item
                | of the setting controller collection using its name "DNBIgpOlpAutoSettingCtrl"
                | as follows:
                | 
                |  Dim settingControllers1 As SettingControllers
                |  Set settingControllers1 = CATIA.SettingControllers
                |  Dim DNBIAIgpOlpSettingAtt1 As SettingController
                |  Set DNBIAIgpOlpSettingAtt1 = settingControllers1.Item("DNBIgpOlpAutoSettingCtrl")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.igp_olp_setting_att = com_object

    @property
    def downloader(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Downloader() As CATBSTR
                | 
                |     Returns or sets value of OLP Translator parameter.
                |     Role: The OLP Translator setting parameter stores the name of currently
                |     selected downloader, also known as the XSLT translator.

        :rtype: str
        """

        return self.igp_olp_setting_att.Downloader

    @downloader.setter
    def downloader(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.Downloader = value

    @property
    def downloader_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DownloaderDir() As CATBSTR
                | 
                |     Returns or sets value of OLP Translator Directory
                |     parameter.
                |     Role: The OLP Translator Directory setting parameter stores the full file
                |     path to directory where OLP downloaders, also known as XSLT translators, are
                |     stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.DownloaderDir

    @downloader_dir.setter
    def downloader_dir(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.DownloaderDir = value

    @property
    def existing_task_treatment(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExistingTaskTreatment() As long
                | 
                |     Returns or sets value of OLP Existing Task Treatment On Upload
                |     parameter.
                |     Role: The OLP Existing Task Treatment On Upload setting parameter
                |     determines how will the existing robot tasks with identical names as the tasks
                |     to be uploaded be treated during upload.
                |     Legal values:
                |     2 Delete existing robot tasks and all the referenced tags
                |     1 Delete existing robot tasks only
                |     0 Do not delete existing robot tasks

        :rtype: int
        """

        return self.igp_olp_setting_att.ExistingTaskTreatment

    @existing_task_treatment.setter
    def existing_task_treatment(self, value: int):
        """
        :param int value:
        """

        self.igp_olp_setting_att.ExistingTaskTreatment = value

    @property
    def java_class_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JavaClassPath() As CATBSTR
                | 
                |     Returns or sets value of OLP Java Class Path parameter.
                |     Role: The OLP Java Class Path setting parameter stores the full file path
                |     to Java JAR files required to proper functioning of OLP download.

        :rtype: str
        """

        return self.igp_olp_setting_att.JavaClassPath

    @java_class_path.setter
    def java_class_path(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.JavaClassPath = value

    @property
    def java_exe(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JavaExe() As CATBSTR
                | 
                |     Returns or sets value of OLP Java Executable parameter.
                |     Role: The OLP Java Executable setting parameter stores the full file path
                |     to java.exe file of Java JRE 1_4_1, or later.

        :rtype: str
        """

        return self.igp_olp_setting_att.JavaExe

    @java_exe.setter
    def java_exe(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.JavaExe = value

    @property
    def nrl_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NRLDir() As CATBSTR
                | 
                |     Returns or sets value of NRL configuration file directory
                |     parameter.
                |     Role: The NRL configuration file directory parameter stores the full file
                |     path to directory where NRL configuration files are stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.NRLDir

    @nrl_dir.setter
    def nrl_dir(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.NRLDir = value

    @property
    def nrl_teach_dialog_display_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NRLTeachDialogDisplayMode() As long
                | 
                |     Returns or sets value of OLPNRLTeachDialogDisplay
                |     parameter.
                |     Role: The OLPNRLTeachDialogDisplay setting parameter determines whether NRL
                |     Teach dialog will be displayed while creating and/or V5 editing of RobotMotion
                |     activities.
                |     Legal values:
                |     1 NRL Teach dialog will be hidden
                |     0 NRL Teach dialog will remain displayed

        :rtype: int
        """

        return self.igp_olp_setting_att.NRLTeachDialogDisplayMode

    @nrl_teach_dialog_display_mode.setter
    def nrl_teach_dialog_display_mode(self, value: int):
        """
        :param int value:
        """

        self.igp_olp_setting_att.NRLTeachDialogDisplayMode = value

    @property
    def robot_program_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RobotProgramDir() As CATBSTR
                | 
                |     Returns or sets value of OLP Directory parameter.
                |     Role: The OLP Directory setting parameter stores the full file path to
                |     directory where native robot language programs on upload should be stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.RobotProgramDir

    @robot_program_dir.setter
    def robot_program_dir(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.RobotProgramDir = value

    @property
    def uploader(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Uploader() As CATBSTR
                | 
                |     Returns or sets value of OLP Parser parameter.
                |     Role: The OLP Parser setting parameter stores the name of currently
                |     selected uploader, also known as the Java Parser.

        :rtype: str
        """

        return self.igp_olp_setting_att.Uploader

    @uploader.setter
    def uploader(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.Uploader = value

    @property
    def uploader_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UploaderDir() As CATBSTR
                | 
                |     Returns or sets value of OLP Parser Directory parameter.
                |     Role: The OLP Parser Directory setting parameter stores the full file path
                |     to directory where OLP uploaders, also known as Java Parsers, are stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.UploaderDir

    @uploader_dir.setter
    def uploader_dir(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.UploaderDir = value

    @property
    def xml_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property XMLDir() As CATBSTR
                | 
                |     Returns or sets value of OLP XML Directory parameter.
                |     Role: The OLP XML Directory setting parameter stores the full file path to
                |     directory where XML file created during download, named simResult.xml, is
                |     stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.XMLDir

    @xml_dir.setter
    def xml_dir(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.XMLDir = value

    @property
    def xml_schema(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property XMLSchema() As CATBSTR
                | 
                |     Returns or sets value of OLP XML Schema parameter.
                |     Role: The OLP XML Schema setting parameter stores the full file path to an
                |     W3C XML Schema file, used for XML file validation on upload, is stored.

        :rtype: str
        """

        return self.igp_olp_setting_att.XMLSchema

    @xml_schema.setter
    def xml_schema(self, value: str):
        """
        :param str value:
        """

        self.igp_olp_setting_att.XMLSchema = value

    def get_downloader_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDownloaderDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Translator Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetDownloaderDirInfo(io_admin_level, io_locked)

    def get_downloader_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDownloaderInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Translator setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetDownloaderInfo(io_admin_level, io_locked)

    def get_existing_task_treatment_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExistingTaskTreatmentInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Existing Task Treatment On Upload
                |     setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetExistingTaskTreatmentInfo(io_admin_level, io_locked)

    def get_java_class_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetJavaClassPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Java Class Path setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetJavaClassPathInfo(io_admin_level, io_locked)

    def get_java_exe_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetJavaExeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Java Executable setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetJavaExeInfo(io_admin_level, io_locked)

    def get_nrl_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNRLDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the NRL configuration file directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetNRLDirInfo(io_admin_level, io_locked)

    def get_nrl_teach_dialog_display_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNRLTeachDialogDisplayModeInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLPNRLTeachDialogDisplay setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetNRLTeachDialogDisplayModeInfo(io_admin_level, io_locked)

    def get_robot_program_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRobotProgramDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetRobotProgramDirInfo(io_admin_level, io_locked)

    def get_uploader_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUploaderDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Parser Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetUploaderDirInfo(io_admin_level, io_locked)

    def get_uploader_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUploaderInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP Parser setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetUploaderInfo(io_admin_level, io_locked)

    def get_xml_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetXMLDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP XML Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetXMLDirInfo(io_admin_level, io_locked)

    def get_xml_schema_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetXMLSchemaInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the OLP XML Schema setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.igp_olp_setting_att.GetXMLSchemaInfo(io_admin_level, io_locked)

    def set_downloader_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDownloaderDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Translator Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetDownloaderDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_downloader_dir_lock'
        # # vba_code = """
        # # Public Function set_downloader_dir_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetDownloaderDirLock iLocked
        # #     set_downloader_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_downloader_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDownloaderLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Translator setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetDownloaderLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_downloader_lock'
        # # vba_code = """
        # # Public Function set_downloader_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetDownloaderLock iLocked
        # #     set_downloader_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_existing_task_treatment_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExistingTaskTreatmentLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Existing Task Treatment On Upload
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetExistingTaskTreatmentLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_existing_task_treatment_lock'
        # # vba_code = """
        # # Public Function set_existing_task_treatment_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetExistingTaskTreatmentLock iLocked
        # #     set_existing_task_treatment_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_java_class_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJavaClassPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Java Class Path parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetJavaClassPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_java_class_path_lock'
        # # vba_code = """
        # # Public Function set_java_class_path_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetJavaClassPathLock iLocked
        # #     set_java_class_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_java_exe_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJavaExeLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Java Executable parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetJavaExeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_java_exe_lock'
        # # vba_code = """
        # # Public Function set_java_exe_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetJavaExeLock iLocked
        # #     set_java_exe_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_nrl_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNRLDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the NRL configuration file directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetNRLDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_nrl_dir_lock'
        # # vba_code = """
        # # Public Function set_nrl_dir_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetNRLDirLock iLocked
        # #     set_nrl_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_nrl_teach_dialog_display_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNRLTeachDialogDisplayModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLPNRLTeachDialogDisplay parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetNRLTeachDialogDisplayModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_nrl_teach_dialog_display_mode_lock'
        # # vba_code = """
        # # Public Function set_nrl_teach_dialog_display_mode_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetNRLTeachDialogDisplayModeLock iLocked
        # #     set_nrl_teach_dialog_display_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_robot_program_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRobotProgramDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Directory setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetRobotProgramDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_robot_program_dir_lock'
        # # vba_code = """
        # # Public Function set_robot_program_dir_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetRobotProgramDirLock iLocked
        # #     set_robot_program_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_uploader_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUploaderDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Parser Directory setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetUploaderDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_uploader_dir_lock'
        # # vba_code = """
        # # Public Function set_uploader_dir_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetUploaderDirLock iLocked
        # #     set_uploader_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_uploader_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUploaderLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP Parser setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetUploaderLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_uploader_lock'
        # # vba_code = """
        # # Public Function set_uploader_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetUploaderLock iLocked
        # #     set_uploader_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_xml_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetXMLDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP XML Directory setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetXMLDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_xml_dir_lock'
        # # vba_code = """
        # # Public Function set_xml_dir_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetXMLDirLock iLocked
        # #     set_xml_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_xml_schema_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetXMLSchemaLock(boolean iLocked)
                | 
                |     Locks or unlocks the OLP XML Schema setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.igp_olp_setting_att.SetXMLSchemaLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_xml_schema_lock'
        # # vba_code = """
        # # Public Function set_xml_schema_lock(igp_olp_setting_att)
        # #     Dim iLocked (2)
        # #     igp_olp_setting_att.SetXMLSchemaLock iLocked
        # #     set_xml_schema_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'IgpOlpSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.shuttle import Shuttle
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Shuttles(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Shuttles
                | 
                | The interface to access a CATIAShuttles
                | 
                | Using this prefered syntax will enable mkdoc to document your
                | class.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Shuttle)
        self.shuttles = com_object

    def add(self) -> Shuttle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As Shuttle
                | 
                |     Creates a new Shuttle and adds it to the Shuttles
                |     collection.
                | 
                |     Returns:
                |         The created Shuttle 
                |     Example:
                |         The following example creates a Shuttle newShuttle in the Shuttles
                |         collection.
                | 
                |          Set newShuttles = Shuttles.Add

        :rtype: Shuttle
        """
        return Shuttle(self.shuttles.Add())

    def add_from_sel(self) -> Shuttle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddFromSel() As Shuttle
                | 
                |     Creates a new Shuttle from the selection and adds it to the Shuttles
                |     collection.
                | 
                |     Returns:
                |         The created Shuttle 
                |     Example:
                |         The following example creates a Shuttle newShuttle in the Shuttles
                |         collection.
                | 
                |          Set newShuttles = Shuttles.Add

        :rtype: Shuttle
        """
        return Shuttle(self.shuttles.AddFromSel())

    def item(self, i_index: cat_variant) -> Shuttle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Shuttle

        :param cat_variant i_index:
        :rtype: Shuttle
        """
        return Shuttle(self.shuttles.Item(i_index))

    def remove(self, i_shuttle: Shuttle) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(Shuttle iShuttle)

        :param Shuttle i_shuttle:
        :rtype: None
        """
        return self.shuttles.Remove(i_shuttle.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(shuttles)
        # #     Dim iShuttle (2)
        # #     shuttles.Remove iShuttle
        # #     remove = iShuttle
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Shuttles(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_entity import AnalysisEntity
from pycatia.knowledge_interfaces.parameters import Parameters


class AnalysisSensor(AnalysisEntity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAnalysisInterfaces.AnalysisEntity
                |                         AnalysisSensor
                | 
                | Represent the analysis sensor.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_sensor = com_object

    @property
    def out_put_parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutPutParameters() As Parameters (Read Only)
                | 
                |     Returns the collection object containing the sensor
                |     parameters.
                | 
                |     Example:
                |         The following example returns in params the parameters computed by the
                |         sensor:
                | 
                |          Dim AnalysisSensor1 As AnalysisSensor
                |          Dim params As CATIAParameters
                |          Set params = AnalysisSensor1.OutPutParameters

        :rtype: Parameters
        """

        return Parameters(self.analysis_sensor.OutPutParameters)

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     Update the sensor. Computation of OutPutParameters if
                |     needed.
                | 
                |     Example:
                |         The following example computes the sensor:
                | 
                |          Dim AnalysisSensor1 As AnalysisSensor
                |          AnalysisSensor1.Update

        :rtype: None
        """
        return self.analysis_sensor.Update()

    def __repr__(self):
        return f'AnalysisSensor(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_output_request import ABQOutputRequest


class ABQDataOutputRequest(ABQOutputRequest):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQOutputRequest
                |                         ABQDataOutputRequest
                | 
                | Represents an Abaqus data output request (ABQDataOutputRequest)
                | object.
                | Role: Access an Abaqus data output request object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_data_output_request = com_object

    def set_specified_output_variables(self, i_variable_name_bstr: str, i_dat_output_var_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpecifiedOutputVariables(CATBSTR iVariableNameBSTR,
                | ABQDatOutputVarType iDatOutputVarType)
                | 
                |     Sets the specified variables and category type for which results are
                |     requested.
                | 
                |     Parameters:
                | 
                |         iVariableNameBSTR
                |             The list of variables for which output is requested For example: If
                |             user wants to request for output for variables 'U' and 'S', then
                |             iVariableNameBSTR will be "U, S" 
                |         iDatOutputVarType
                |             The variable type: Node based, Element based etc.
                | 
                |             Legal values:
                | 
                |             "DATOUTPUTTYPE_NODE"
                |             "DATOUTPUTTYPE_ELEMENT"
                |             "DATOUTPUTTYPE_CONTACT"
                |             "DATOUTPUTTYPE_ENERGY"

        :param str i_variable_name_bstr:
        :param int i_dat_output_var_type: enum abq_dat_output_var_type
        :rtype: None
        """
        return self.abq_data_output_request.SetSpecifiedOutputVariables(i_variable_name_bstr, i_dat_output_var_type)

    def unset_output_type(self, i_dat_output_var_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetOutputType(ABQDatOutputVarType iDatOutputVarType)
                | 
                |     Unset the data output request for specified type
                | 
                |     Parameters:
                | 
                |         iDatOutputVarType
                |             The variable type: Node based, Element based etc. User can unset
                |             the request for the variable type, if user does not want result for this type
                |             and it it was requested in previous step
                | 
                |             Legal values:
                | 
                |             "DATOUTPUTTYPE_NODE"
                |             "DATOUTPUTTYPE_ELEMENT"
                |             "DATOUTPUTTYPE_CONTACT"
                |             "DATOUTPUTTYPE_ENERGY"

        :param int i_dat_output_var_type: enum abq_dat_output_var_type
        :rtype: None
        """
        return self.abq_data_output_request.UnsetOutputType(i_dat_output_var_type)

    def __repr__(self):
        return f'ABQDataOutputRequest(name="{self.name}")'
